==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/ENTERPRISESEARCHSETUPREPOSITORYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ENTERPRISESEARCHSETUPREPOSITORYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ENTERPRISESEARCHSETUPREPOSITORYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTERESTCENTERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTERPRISESEARCHSETUPREPOSITORYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENTERPRISESEARCHSETUPREPOSITORYID_Type", propOrder = {
    "interestcenterid",
    "enterprisesearchsetuprepositorycode",
    "description"
})
public class ENTERPRISESEARCHSETUPREPOSITORYID_Type {

    @XmlElement(name = "INTERESTCENTERID", required = true)
    protected INTERESTCENTERID_Type interestcenterid;
    @XmlElement(name = "ENTERPRISESEARCHSETUPREPOSITORYCODE", required = true)
    protected String enterprisesearchsetuprepositorycode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété interestcenterid.
     * 
     * @return
     *     possible object is
     *     {@link INTERESTCENTERID_Type }
     *     
     */
    public INTERESTCENTERID_Type getINTERESTCENTERID() {
        return interestcenterid;
    }

    /**
     * Définit la valeur de la propriété interestcenterid.
     * 
     * @param value
     *     allowed object is
     *     {@link INTERESTCENTERID_Type }
     *     
     */
    public void setINTERESTCENTERID(INTERESTCENTERID_Type value) {
        this.interestcenterid = value;
    }

    /**
     * Obtient la valeur de la propriété enterprisesearchsetuprepositorycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTERPRISESEARCHSETUPREPOSITORYCODE() {
        return enterprisesearchsetuprepositorycode;
    }

    /**
     * Définit la valeur de la propriété enterprisesearchsetuprepositorycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTERPRISESEARCHSETUPREPOSITORYCODE(String value) {
        this.enterprisesearchsetuprepositorycode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/ENTERPRISESEARCHSETUPREPOSITORYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ENTERPRISESEARCHSETUPREPOSITORYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ENTERPRISESEARCHSETUPREPOSITORYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTERESTCENTERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTERPRISESEARCHSETUPREPOSITORYCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ENTERPRISESEARCHSETUPREPOSITORYID_Type", propOrder = {
    "interestcenterid",
    "enterprisesearchsetuprepositorycode",
    "description"
})
public class ENTERPRISESEARCHSETUPREPOSITORYID_Type {

    @XmlElement(name = "INTERESTCENTERID", required = true)
    protected INTERESTCENTERID_Type interestcenterid;
    @XmlElement(name = "ENTERPRISESEARCHSETUPREPOSITORYCODE", required = true)
    protected String enterprisesearchsetuprepositorycode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the interestcenterid property.
     * 
     * @return
     *     possible object is
     *     {@link INTERESTCENTERID_Type }
     *     
     */
    public INTERESTCENTERID_Type getINTERESTCENTERID() {
        return interestcenterid;
    }

    /**
     * Sets the value of the interestcenterid property.
     * 
     * @param value
     *     allowed object is
     *     {@link INTERESTCENTERID_Type }
     *     
     */
    public void setINTERESTCENTERID(INTERESTCENTERID_Type value) {
        this.interestcenterid = value;
    }

    /**
     * Gets the value of the enterprisesearchsetuprepositorycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTERPRISESEARCHSETUPREPOSITORYCODE() {
        return enterprisesearchsetuprepositorycode;
    }

    /**
     * Sets the value of the enterprisesearchsetuprepositorycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTERPRISESEARCHSETUPREPOSITORYCODE(String value) {
        this.enterprisesearchsetuprepositorycode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
